@@ -1,5 +1,5 @@
 #
-# Copyright (C) 2003-2007 by the gtk2-perl team (see the file AUTHORS for
+# Copyright (C) 2003-2006 by the gtk2-perl team (see the file AUTHORS for
 # the full list)
 #
 # This library is free software; you can redistribute it and/or modify it under
@@ -16,7 +16,7 @@
 # along with this library; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
 #
-# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/Gtk2.pm,v 1.100.2.7 2007/08/04 13:49:08 kaffeetisch Exp $
+# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/Gtk2.pm,v 1.101 2006/12/04 19:58:51 kaffeetisch Exp $
 #
 
 package Gtk2;
@@ -35,7 +35,7 @@ eval "use Cairo;";
 
 require DynaLoader;
 
-our $VERSION = '1.146';
+our $VERSION = '1.150';
 
 our @ISA = qw(DynaLoader);
 
@@ -102,22 +102,6 @@ use overload
 	'&{}' => sub { \&Gtk2::TreeSortable::IterCompareFunc::invoke },
 	fallback => 1;
 
-package Gtk2::TreeModelSort;
-
-# We forgot to prepend Gtk2::TreeModel to @Gtk2::TreeModelSort::ISA.  So this
-# hack is here to make sure that $model_sort->get resolves to
-# Gtk2::TreeModel::get when appropriate and to Glib::Object::get otherwise, so
-# we stay backwards compatible.
-sub get {
-	if (@_ > 1 and ref $_[1] eq 'Gtk2::TreeIter') {
-		# called as $model->get ($iter, columns...);
-		return Gtk2::TreeModel::get (@_);
-	} else {
-		# called as $model->get (names...);
-		return Glib::Object::get (@_);
-	}
-}
-
 package Gtk2;
 
 
@@ -234,7 +218,7 @@ The gtk2-perl team:
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2003-2007 by the gtk2-perl team.
+Copyright 2003-2006 by the gtk2-perl team.
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
